#
# spec file for package intel-ipsec-mb
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2022, Intel Corporation
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global major        1
%global minor        5
%global patch        0

# GitHub properties
%global githubver    %{major}.%{minor}
%global githubfull   %{name}-%{githubver}

%global rpm_name     libIPSec_MB

Name:           intel-ipsec-mb
Summary:        IPSec cryptography library optimized for Intel Architecture
Release:        1.2
Version:        %{major}.%{minor}.%{patch}
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://github.com/intel/%{name}
Source0:        https://github.com/intel/%{name}/archive/v%{githubver}.tar.gz#/%{githubfull}.tar.gz
ExclusiveArch:  x86_64
BuildRequires:  gcc >= 4.8.3
BuildRequires:  make
BuildRequires:  nasm >= 2.14

%description
An IPSec cryptography library optimized for Intel Architecture
and primarily targeted at packet processing applications.

%package devel
Summary:        Headers for the Intel IPSec cryptographic library
Requires:       %{rpm_name}%{major}%{?_isa} = %{version}-%{release}
Group:          Development/Libraries/C and C++

%description devel
An IPSec cryptography library optimized for Intel Architecture
and primarily targeted at packet processing applications.

This package contains the headers for building programs with the library.

%package -n %{rpm_name}%{major}
Summary:        IPSec cryptography library optimized for Intel Architecture
Group:          System/Libraries

%description -n %{rpm_name}%{major}
An IPSec cryptography library optimized for Intel Architecture
and primarily targeted at packet processing applications.

%prep
%autosetup -n %{name}-%{githubver}

%build
cd lib
%make_build EXTRA_CFLAGS='%{optflags}'

%install
install -d %{buildroot}/%{_includedir}
install -m 0644 %{_builddir}/%{githubfull}/lib/intel-ipsec-mb.h %{buildroot}/%{_includedir}
install -d %{buildroot}/%{_libdir}
install -s -m 0755 %{_builddir}/%{githubfull}/lib/libIPSec_MB.so.%{version} %{buildroot}/%{_libdir}
install -d %{buildroot}/%{_mandir}/man7
install -m 0444 lib/libipsec-mb.7 %{buildroot}/%{_mandir}/man7
install -m 0444 lib/libipsec-mb-dev.7 %{buildroot}/%{_mandir}/man7
cd %{buildroot}/%{_libdir}
ln -s libIPSec_MB.so.%{version} libIPSec_MB.so.%{major}
ln -s libIPSec_MB.so.%{version} libIPSec_MB.so

%files -n %{rpm_name}%{major}
%license LICENSE
%{_libdir}/libIPSec_MB.so.%{version}
%{_libdir}/libIPSec_MB.so.%{major}

%files devel
%doc README ReleaseNotes.txt
%{_includedir}/intel-ipsec-mb.h
%{_mandir}/man7/libipsec-mb.7.gz
%{_mandir}/man7/libipsec-mb-dev.7.gz
%{_libdir}/libIPSec_MB.so

%post  -n %{rpm_name}%{major} -p /sbin/ldconfig
%postun -n %{rpm_name}%{major} -p /sbin/ldconfig

%changelog
* Fri Nov 17 2023 Tomasz Kantecki <tomasz.kantecki@intel.com>
- Update to v1.5:
  * CMake MinGW support added.
  * QUIC CHACHA20-POLY1305 and CHACHA20 HP API added.
  * AVX2-VAES AES-CTR and AES-GCM implementations added.
  * SSE SM4-ECB and SM4-CBC implementations added.
  * x86-64 SM3 and SM3-HMAC implementations added.
  * Self-Test callback functionality added with message corrupt option.
  * Implemented a workaround for false load-block condition in SSE AES-CBC implementations.
  * Optimized CRC32 algorithms, AES-GCM AVX2 and AES-GCM AVX512 implementations.
  * Updated ACVP app (imb-acvp) to support libacvp v2.0+.
  * Test vector format standardized for various algorithms (CBC/CFB/CTR/ECB/DES/GCM/CCM/CHACHA20-POLY/SNOW3G/ZUC/KASUMI/SNOW-V).
  * Extended xvalid app to test burst API.
  * Burst API is used by default in imb-perf tool.
- Fixed issues:
  * CMake files ignore LIB_INSTALL_DIR and incorrectly put the shared libraries in /usr/lib (issue #125)
  * The CMakefile does not install the headers (normal Makefile does) (issue #126)
  * File ./test/acvp-app/utils.o is not removed after "make clean" (issue #130)
  * nasm can not find .inc .asm files when building with CMake (issue #131)
- More details at https://github.com/intel/intel-ipsec-mb/releases/tag/v1.5
* Tue Aug  8 2023 Tomasz Kantecki <tomasz.kantecki@intel.com>
- Update to v1.4:
  * POLY1305 AVX2 with AVX-IFMA instructions added.
  * Optimized GHASH component in AVX512 VAES (type2) AES-GCM implementation.
  * Implemented a workaround for false load-block condition in SSE and AVX2 AES-GCM implementations.
  * Removed AVX AES-GCM implementation, its API symbols map to the SSE implementation.
  * QUIC header protection API added.
  * QUIC AES-GCM-128/256 AEAD API added.
  * Removed v0.53 (and older) compatibility symbol mapping (NO_COMPAT_IMB_API_053 not defined).
  * ZUC AVX2-GFNI implementation added.
  * SHA-NI instructions enabled to use in SHA1/224/256 direct API
  * New API (imb_set_session) added to be used with burst API, helping speeding up the crypto scheduling.
  * New API added to calculate IPAD/OPAD for SHAx-HMAC.
  * New direct API added to calculate DES-CFB and AES-CFB-256 on a single block.
- Fixed issues:
  * MB_MGR corruption at initialization
  * Performance scaling
- More details at https://github.com/intel/intel-ipsec-mb/releases/tag/v1.4
* Wed Oct  5 2022 Stephen Mcintyre <stephen.mcintyre@intel.com>
- Update for release package v1.3
* Thu Mar 31 2022 Jan Engelhardt <jengelh@inai.de>
- Move documentation out of libintel-ipsec-mb1
  (conflicts with a future libintel-ipsec-mb2).
* Fri Mar 11 2022 Stephen McIntyre <stephen.mcintyre@intel.com>
- initial version of the SUSE package
